// created by jay 0.7 (c) 1998 Axel.Schreiner@informatik.uni-osnabrueck.de

#line 2 "Parser.jay"
using System.Text;
using System.IO;
using System.Collections;
using System;

namespace Mono.Debugger.Frontends.CommandLine
{
	public class Parser
	{
		string name;
		ScriptingContext current_context;
		MyTextReader reader;
		bool do_quit = false;

		protected bool yacc_verbose_flag = false;

		public bool yacc_verbose {
			set {
				yacc_verbose_flag = value;
			}

			get {
				return yacc_verbose_flag;
			}
		}

		public bool Quit {
			get {
				return do_quit;
			}
		}

		Tokenizer lexer;

		public Tokenizer Lexer {
			get {
				return lexer;
			}
		}		   

#line default

  /** simplified error message.
      @see <a href="#yyerror(java.lang.String, java.lang.String[])">yyerror</a>
    */
  public void yyerror (string message) {
    yyerror(message, null);
  }

  /** (syntax) error message.
      Can be overwritten to control message format.
      @param message text to be displayed.
      @param expected vector of acceptable tokens, if available.
    */
  public void yyerror (string message, string[] expected) {
    if ((expected != null) && (expected.Length  > 0)) {
      System.Console.Write (message+", expecting");
      for (int n = 0; n < expected.Length; ++ n)
        System.Console.Write (" "+expected[n]);
        System.Console.WriteLine ();
    } else
      System.Console.WriteLine (message);
  }

  /** debugging support, requires the package jay.yydebug.
      Set to null to suppress debugging messages.
    */
  protected yydebug.yyDebug debug;

  protected static  int yyFinal = 2;
  public static  string [] yyRule = {
    "$accept : command_loop",
    "command_loop :",
    "command_loop : command_loop command EOL",
    "command_loop : command_loop EOL",
    "command_loop : command_loop EOF",
    "command_loop : QUIT EOL",
    "command : generated_command",
    "command : other_command",
    "command : assert_command",
    "generated_command : CONTINUE process_expression",
    "generated_command : STEP process_expression",
    "generated_command : NEXT process_expression",
    "generated_command : STEPI process_expression",
    "generated_command : NATIVE STEPI process_expression",
    "generated_command : NEXTI process_expression",
    "generated_command : FINISH process_expression",
    "generated_command : BACKTRACE process_expression",
    "generated_command : UP process_expression",
    "generated_command : DOWN process_expression",
    "generated_command : KILL",
    "generated_command : RUN",
    "generated_command : SHOW PROCESSES",
    "generated_command : SHOW REGISTERS frame_expression",
    "generated_command : SHOW PARAMETERS frame_expression",
    "generated_command : SHOW LOCALS frame_expression",
    "generated_command : SHOW MODULES",
    "generated_command : SHOW SOURCES module_list_expression",
    "generated_command : SHOW METHODS source_list_expression",
    "generated_command : SHOW BREAKPOINTS",
    "generated_command : SHOW THREADGROUPS",
    "generated_command : SHOW TYPE variable_expression",
    "generated_command : BREAK thread_group_expression source_expression",
    "generated_command : BREAKPOINT ENABLE breakpoint_number_expression",
    "generated_command : BREAKPOINT DISABLE breakpoint_number_expression",
    "generated_command : BREAKPOINT DELETE breakpoint_number_expression",
    "generated_command : FRAME frame_expression",
    "generated_command : DISASSEMBLE frame_expression",
    "generated_command : DISASSEMBLE METHOD frame_expression",
    "generated_command : PROCESS process_expression",
    "generated_command : BACKGROUND process_expression",
    "generated_command : STOP process_expression",
    "generated_command : MODULE module_list_expression module_operations",
    "generated_command : THREADGROUP CREATE STRING",
    "generated_command : THREADGROUP ADD STRING process_list_expression",
    "generated_command : THREADGROUP REMOVE STRING process_list_expression",
    "generated_command : LIST source_expression",
    "generated_command : LIST CONTINUE",
    "other_command : SAVE STRING",
    "other_command : SET BANG IDENTIFIER ASSIGN variable_expression",
    "other_command : PRINT expression",
    "other_command : EXAMINE examine_format variable_expression",
    "other_command : CALL variable_expression",
    "other_command : START program_arguments_expression",
    "kind : UNKNOWN",
    "kind : FUNDAMENTAL",
    "kind : ARRAY",
    "kind : STRUCT",
    "kind : CLASS",
    "kind : POINTER",
    "assert_command : ASSERT KIND kind variable_expression",
    "assert_command : ASSERT ACCESSIBLE variable_expression",
    "assert_command : ASSERT NOT ACCESSIBLE variable_expression",
    "assert_command : ASSERT TYPE STRING variable_expression",
    "assert_command : ASSERT CONTENTS STRING variable_expression",
    "assert_command : ASSERT LINE INTEGER",
    "expression : LENGTH OPEN_PARENS variable_expression CLOSE_PARENS",
    "expression : LOWER OPEN_PARENS variable_expression CLOSE_PARENS",
    "expression : UPPER OPEN_PARENS variable_expression CLOSE_PARENS",
    "expression : NUMBER",
    "expression : INTEGER",
    "expression : expression binary_operator expression",
    "expression : OPEN_PARENS expression CLOSE_PARENS",
    "expression : variable_expression",
    "variable_expression : STAR variable_expression",
    "variable_expression : BANG IDENTIFIER",
    "variable_expression : frame_expression DOLLAR IDENTIFIER",
    "variable_expression : frame_expression PERCENT NUMBER",
    "variable_expression : frame_expression PERCENT IDENTIFIER opt_regoffset",
    "variable_expression : variable_expression DOT IDENTIFIER",
    "variable_expression : variable_expression MINUS OP_GT IDENTIFIER",
    "variable_expression : variable_expression OPEN_BRACKET expression CLOSE_BRACKET",
    "variable_expression : PARENT OPEN_PARENS variable_expression CLOSE_PARENS",
    "variable_expression : OPEN_PARENS variable_expression CLOSE_PARENS",
    "program_arguments_expression : program_arglist",
    "program_arglist : STRING",
    "program_arglist : program_arglist STRING",
    "examine_format :",
    "examine_format : DIV integer_or_number",
    "opt_regoffset :",
    "opt_regoffset : PLUS integer_or_number",
    "opt_regoffset : MINUS integer_or_number",
    "integer_or_number : INTEGER",
    "integer_or_number : NUMBER",
    "breakpoint_number_expression : INTEGER",
    "thread_group_expression :",
    "thread_group_expression : OP_LT IDENTIFIER OP_GT",
    "thread_group_expression : OP_LT GLOBAL OP_GT",
    "process_expression :",
    "process_expression : AT INTEGER",
    "frame_expression : process_expression",
    "frame_expression : process_expression HASH INTEGER",
    "opt_line :",
    "opt_line : COLON INTEGER",
    "source_expression : frame_expression",
    "source_expression : frame_expression IDENTIFIER opt_line",
    "source_expression : frame_expression INTEGER",
    "source_expression : STRING",
    "source_expression : STRING COLON INTEGER",
    "source_expression : BANG INTEGER",
    "module_list_expression : number_list",
    "source_list_expression : number_list",
    "process_list_expression : number_list",
    "number_list : INTEGER",
    "number_list : number_list COMMA INTEGER",
    "module_operation : IGNORE",
    "module_operation : UNIGNORE",
    "module_operation : BANG IGNORE",
    "module_operation : STEP",
    "module_operation : BANG STEP",
    "module_operation : SHOW BREAKPOINTS",
    "module_operations : module_operation_list",
    "module_operation_list : module_operation",
    "module_operation_list : module_operation_list module_operation",
    "binary_operator : STAR",
    "binary_operator : PLUS",
    "binary_operator : MINUS",
    "binary_operator : DIV",
  };
  protected static  string [] yyName = {    
    "end-of-file",null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,"QUIT","EOL","EOF","NONE","ERROR",
    "IDENTIFIER","INTEGER","NUMBER","STRING","HASH","AT","PERCENT",
    "DOLLAR","DOT","BANG","COMMA","ASSIGN","STAR","PLUS","MINUS","DIV",
    "OPEN_PARENS","CLOSE_PARENS","OPEN_BRACKET","CLOSE_BRACKET","OP_LT",
    "OP_GT","COLON","PROCESSES","REGISTERS","PARAMETERS","LOCALS","TYPE",
    "METHOD","PARENT","LENGTH","LOWER","UPPER","KIND","ACCESSIBLE",
    "CONTENTS","LINE","NOT","UNKNOWN","FUNDAMENTAL","ARRAY","STRUCT",
    "CLASS","POINTER","MODULES","SOURCES","METHODS","BREAKPOINTS",
    "THREADGROUPS","GLOBAL","FRAME","START","SHOW","PROCESS","CONTINUE",
    "BACKTRACE","UP","DOWN","STEP","NEXT","STEPI","NEXTI","FINISH",
    "BREAK","PRINT","DISASSEMBLE","SET","ASSERT","BREAKPOINT","SAVE",
    "KILL","THREADGROUP","SEARCH","LIST","RUN","EXAMINE","CALL","NATIVE",
    "SELECT","BACKGROUND","STOP","MODULE","IGNORE","UNIGNORE","ALL",
    "ENABLE","DISABLE","DELETE","CREATE","ADD","REMOVE","HELP",
  };

  /** index-checked interface to yyName[].
      @param token single character or %token value.
      @return token name or [illegal] or [unknown].
    */
  public static string yyname (int token) {
    if ((token < 0) || (token > yyName.Length)) return "[illegal]";
    string name;
    if ((name = yyName[token]) != null) return name;
    return "[unknown]";
  }

  /** computes list of expected tokens on error by tracing the tables.
      @param state for which to compute the list.
      @return list of token names.
    */
  protected string[] yyExpecting (int state) {
    int token, n, len = 0;
    bool[] ok = new bool[yyName.Length];

    if ((n = yySindex[state]) != 0)
      for (token = n < 0 ? -n : 0;
           (token < yyName.Length) && (n+token < yyTable.Length); ++ token)
        if (yyCheck[n+token] == token && !ok[token] && yyName[token] != null) {
          ++ len;
          ok[token] = true;
        }
    if ((n = yyRindex[state]) != 0)
      for (token = n < 0 ? -n : 0;
           (token < yyName.Length) && (n+token < yyTable.Length); ++ token)
        if (yyCheck[n+token] == token && !ok[token] && yyName[token] != null) {
          ++ len;
          ok[token] = true;
        }

    string [] result = new string[len];
    for (n = token = 0; n < len;  ++ token)
      if (ok[token]) result[n++] = yyName[token];
    return result;
  }

  /** the generated parser, with debugging messages.
      Maintains a state and a value stack, currently with fixed maximum size.
      @param yyLex scanner.
      @param yydebug debug message writer implementing yyDebug, or null.
      @return result of the last reduction, if any.
      @throws yyException on irrecoverable parse error.
    */
  public Object yyparse (yyParser.yyInput yyLex, Object yyd)
				 {
    this.debug = (yydebug.yyDebug)yyd;
    return yyparse(yyLex);
  }

  /** initial size and increment of the state/value stack [default 256].
      This is not final so that it can be overwritten outside of invocations
      of yyparse().
    */
  protected int yyMax;

  /** executed at the beginning of a reduce action.
      Used as $$ = yyDefault($1), prior to the user-specified action, if any.
      Can be overwritten to provide deep copy, etc.
      @param first value for $1, or null.
      @return first.
    */
  protected Object yyDefault (Object first) {
    return first;
  }

  /** the generated parser.
      Maintains a state and a value stack, currently with fixed maximum size.
      @param yyLex scanner.
      @return result of the last reduction, if any.
      @throws yyException on irrecoverable parse error.
    */
  public Object yyparse (yyParser.yyInput yyLex)
				{
    if (yyMax <= 0) yyMax = 256;			// initial size
    int yyState = 0;                                   // state stack ptr
    int [] yyStates = new int[yyMax];	                // state stack 
    Object yyVal = null;                               // value stack ptr
    Object [] yyVals = new Object[yyMax];	        // value stack
    int yyToken = -1;					// current input
    int yyErrorFlag = 0;				// #tks to shift

    int yyTop = 0;
    goto skip;
    yyLoop:
    yyTop++;
    skip:
    for (;; ++ yyTop) {
      if (yyTop >= yyStates.Length) {			// dynamically increase
        int[] i = new int[yyStates.Length+yyMax];
        yyStates.CopyTo (i, 0);
        yyStates = i;
        Object[] o = new Object[yyVals.Length+yyMax];
        yyVals.CopyTo (o, 0);
        yyVals = o;
      }
      yyStates[yyTop] = yyState;
      yyVals[yyTop] = yyVal;
      if (debug != null) debug.push(yyState, yyVal);

      yyDiscarded: for (;;) {	// discarding a token does not change stack
        int yyN;
        if ((yyN = yyDefRed[yyState]) == 0) {	// else [default] reduce (yyN)
          if (yyToken < 0) {
            yyToken = yyLex.advance() ? yyLex.token() : 0;
            if (debug != null)
              debug.lex(yyState, yyToken, yyname(yyToken), yyLex.value());
          }
          if ((yyN = yySindex[yyState]) != 0 && ((yyN += yyToken) >= 0)
              && (yyN < yyTable.Length) && (yyCheck[yyN] == yyToken)) {
            if (debug != null)
              debug.shift(yyState, yyTable[yyN], yyErrorFlag-1);
            yyState = yyTable[yyN];		// shift to yyN
            yyVal = yyLex.value();
            yyToken = -1;
            if (yyErrorFlag > 0) -- yyErrorFlag;
            goto yyLoop;
          }
          if ((yyN = yyRindex[yyState]) != 0 && (yyN += yyToken) >= 0
              && yyN < yyTable.Length && yyCheck[yyN] == yyToken)
            yyN = yyTable[yyN];			// reduce (yyN)
          else
            switch (yyErrorFlag) {
  
            case 0:
              yyerror("syntax error", yyExpecting(yyState));
              if (debug != null) debug.error("syntax error");
              goto case 1;
            case 1: case 2:
              yyErrorFlag = 3;
              do {
                if ((yyN = yySindex[yyStates[yyTop]]) != 0
                    && (yyN += Token.yyErrorCode) >= 0 && yyN < yyTable.Length
                    && yyCheck[yyN] == Token.yyErrorCode) {
                  if (debug != null)
                    debug.shift(yyStates[yyTop], yyTable[yyN], 3);
                  yyState = yyTable[yyN];
                  yyVal = yyLex.value();
                  goto yyLoop;
                }
                if (debug != null) debug.pop(yyStates[yyTop]);
              } while (-- yyTop >= 0);
              if (debug != null) debug.reject();
              throw new yyParser.yyException("irrecoverable syntax error");
  
            case 3:
              if (yyToken == 0) {
                if (debug != null) debug.reject();
                throw new yyParser.yyException("irrecoverable syntax error at end-of-file");
              }
              if (debug != null)
                debug.discard(yyState, yyToken, yyname(yyToken),
  							yyLex.value());
              yyToken = -1;
              goto yyDiscarded;		// leave stack alone
            }
        }
        int yyV = yyTop + 1-yyLen[yyN];
        if (debug != null)
          debug.reduce(yyState, yyStates[yyV-1], yyN, yyRule[yyN], yyLen[yyN]);
        yyVal = yyDefault(yyV > yyTop ? null : yyVals[yyV]);
        switch (yyN) {
case 2:
#line 156 "Parser.jay"
  {
		((Command) yyVals[-1+yyTop]).Execute (current_context);
	  }
  break;
case 5:
#line 162 "Parser.jay"
  {
		do_quit = true;
		reader.Close ();
	  }
  break;
case 9:
#line 172 "Parser.jay"
  {
		yyVal = new ContinueCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 10:
#line 176 "Parser.jay"
  {
		yyVal = new StepCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 11:
#line 180 "Parser.jay"
  {
		yyVal = new NextCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 12:
#line 184 "Parser.jay"
  {
		yyVal = new StepInstructionCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 13:
#line 188 "Parser.jay"
  {
		yyVal = new StepNativeInstructionCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 14:
#line 192 "Parser.jay"
  {
		yyVal = new NextInstructionCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 15:
#line 196 "Parser.jay"
  {
		yyVal = new FinishCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 16:
#line 200 "Parser.jay"
  {
		yyVal = new BacktraceCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 17:
#line 204 "Parser.jay"
  {
		yyVal = new UpCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 18:
#line 208 "Parser.jay"
  {
		yyVal = new DownCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 19:
#line 212 "Parser.jay"
  {
		yyVal = new KillCommand ();
	  }
  break;
case 20:
#line 216 "Parser.jay"
  {
		yyVal = new RunCommand ();
	  }
  break;
case 21:
#line 220 "Parser.jay"
  {
		yyVal = new ShowProcessesCommand ();
	  }
  break;
case 22:
#line 224 "Parser.jay"
  {
		yyVal = new ShowRegistersCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 23:
#line 228 "Parser.jay"
  {
		yyVal = new ShowParametersCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 24:
#line 232 "Parser.jay"
  {
		yyVal = new ShowLocalsCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 25:
#line 236 "Parser.jay"
  {
		yyVal = new ShowModulesCommand ();
	  }
  break;
case 26:
#line 240 "Parser.jay"
  {
		yyVal = new ShowSourcesCommand ((ModuleListExpression) yyVals[0+yyTop]);
	  }
  break;
case 27:
#line 244 "Parser.jay"
  {
		yyVal = new ShowMethodsCommand ((SourceListExpression) yyVals[0+yyTop]);
	  }
  break;
case 28:
#line 248 "Parser.jay"
  {
		yyVal = new ShowBreakpointsCommand ();
	  }
  break;
case 29:
#line 252 "Parser.jay"
  {
		yyVal = new ShowThreadGroupsCommand ();
	  }
  break;
case 30:
#line 256 "Parser.jay"
  {
		yyVal = new ShowVariableTypeCommand ((VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 31:
#line 260 "Parser.jay"
  {
		yyVal = new BreakCommand ((ThreadGroupExpression) yyVals[-1+yyTop], (SourceExpression) yyVals[0+yyTop]);
	  }
  break;
case 32:
#line 264 "Parser.jay"
  {
		yyVal = new BreakpointEnableCommand ((BreakpointNumberExpression) yyVals[0+yyTop]);
	  }
  break;
case 33:
#line 268 "Parser.jay"
  {
		yyVal = new BreakpointDisableCommand ((BreakpointNumberExpression) yyVals[0+yyTop]);
	  }
  break;
case 34:
#line 272 "Parser.jay"
  {
		yyVal = new BreakpointDeleteCommand ((BreakpointNumberExpression) yyVals[0+yyTop]);
	  }
  break;
case 35:
#line 276 "Parser.jay"
  {
		yyVal = new FrameCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 36:
#line 280 "Parser.jay"
  {
		yyVal = new DisassembleCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 37:
#line 284 "Parser.jay"
  {
		yyVal = new DisassembleMethodCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 38:
#line 288 "Parser.jay"
  {
		yyVal = new SelectProcessCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 39:
#line 292 "Parser.jay"
  {
		yyVal = new BackgroundProcessCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 40:
#line 296 "Parser.jay"
  {
		yyVal = new StopProcessCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 41:
#line 300 "Parser.jay"
  {
		yyVal = new ModuleOperationCommand ((ModuleListExpression) yyVals[-1+yyTop], (ModuleOperationListExpression) yyVals[0+yyTop]);
	  }
  break;
case 42:
#line 304 "Parser.jay"
  {
		yyVal = new ThreadGroupCreateCommand ((string) yyVals[0+yyTop]);
	  }
  break;
case 43:
#line 308 "Parser.jay"
  {
		yyVal = new ThreadGroupAddCommand ((string) yyVals[-1+yyTop], (ProcessListExpression) yyVals[0+yyTop]);
	  }
  break;
case 44:
#line 312 "Parser.jay"
  {
		yyVal = new ThreadGroupRemoveCommand ((string) yyVals[-1+yyTop], (ProcessListExpression) yyVals[0+yyTop]);
	  }
  break;
case 45:
#line 316 "Parser.jay"
  {
		yyVal = new ListCommand ((SourceExpression) yyVals[0+yyTop]);
	  }
  break;
case 46:
#line 320 "Parser.jay"
  {
		yyVal = new ListCommand (null);
	  }
  break;
case 47:
#line 327 "Parser.jay"
  {
		yyVal = new SaveCommand ((string) yyVals[0+yyTop]);
	  }
  break;
case 48:
#line 331 "Parser.jay"
  {
		yyVal = new ScriptingVariableAssignCommand ((string) yyVals[-2+yyTop], (VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 49:
#line 335 "Parser.jay"
  {
		yyVal = new PrintCommand ((Expression) yyVals[0+yyTop]);
	  }
  break;
case 50:
#line 339 "Parser.jay"
  {
		yyVal = new ExamineCommand ((ExamineCommand.Format) yyVals[-1+yyTop], (VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 51:
#line 343 "Parser.jay"
  {
		yyVal = new CallMethodCommand ((VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 52:
#line 347 "Parser.jay"
  {
		yyVal = new StartCommand ((ProgramArgumentsExpression) yyVals[0+yyTop]);
	  }
  break;
case 53:
#line 354 "Parser.jay"
  {
		yyVal = TargetObjectKind.Unknown;
	  }
  break;
case 54:
#line 358 "Parser.jay"
  {
		yyVal = TargetObjectKind.Fundamental;
	  }
  break;
case 55:
#line 362 "Parser.jay"
  {
		yyVal = TargetObjectKind.Array;
	  }
  break;
case 56:
#line 366 "Parser.jay"
  {
		yyVal = TargetObjectKind.Struct;
	  }
  break;
case 57:
#line 370 "Parser.jay"
  {
		yyVal = TargetObjectKind.Class;
	  }
  break;
case 58:
#line 374 "Parser.jay"
  {
		yyVal = TargetObjectKind.Pointer;
	  }
  break;
case 59:
#line 381 "Parser.jay"
  {
		yyVal = new AssertKindCommand ((TargetObjectKind) yyVals[-1+yyTop], (VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 60:
#line 385 "Parser.jay"
  {
		yyVal = new AssertAccessibleCommand ((VariableExpression) yyVals[0+yyTop], true);
	  }
  break;
case 61:
#line 389 "Parser.jay"
  {
		yyVal = new AssertAccessibleCommand ((VariableExpression) yyVals[0+yyTop], false);
	  }
  break;
case 62:
#line 393 "Parser.jay"
  {
		yyVal = new AssertTypeCommand ((string) yyVals[-1+yyTop], (VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 63:
#line 397 "Parser.jay"
  {
		yyVal = new AssertContentsCommand ((string) yyVals[-1+yyTop], (VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 64:
#line 401 "Parser.jay"
  {
		yyVal = new AssertLineCommand ((int) yyVals[0+yyTop]);
	  }
  break;
case 65:
#line 408 "Parser.jay"
  {
		yyVal = new ArrayLengthExpression ((VariableExpression) yyVals[-1+yyTop]);
	  }
  break;
case 66:
#line 412 "Parser.jay"
  {
		yyVal = new ArrayLowerBoundExpression ((VariableExpression) yyVals[-1+yyTop]);
	  }
  break;
case 67:
#line 416 "Parser.jay"
  {
		yyVal = new ArrayUpperBoundExpression ((VariableExpression) yyVals[-1+yyTop]);
	  }
  break;
case 68:
#line 420 "Parser.jay"
  {
		yyVal = new NumberExpression ((long) yyVals[0+yyTop]);
	  }
  break;
case 69:
#line 424 "Parser.jay"
  {
		yyVal = new NumberExpression ((int) yyVals[0+yyTop]);
	  }
  break;
case 70:
#line 428 "Parser.jay"
  {
		yyVal = new BinaryOperator ((BinaryOperator.Kind) yyVals[-1+yyTop], (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
	  }
  break;
case 71:
#line 432 "Parser.jay"
  {
		yyVal = new ExpressionGroup ((Expression) yyVals[-1+yyTop]);
	  }
  break;
case 72:
#line 436 "Parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 73:
#line 443 "Parser.jay"
  {
		yyVal = new VariableDereferenceExpression ((VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 74:
#line 447 "Parser.jay"
  {
		yyVal = new ScriptingVariableReference ((string) yyVals[0+yyTop]);
	  }
  break;
case 75:
#line 451 "Parser.jay"
  {
		yyVal = new VariableReferenceExpression ((FrameExpression) yyVals[-2+yyTop], (string) yyVals[0+yyTop]);
	  }
  break;
case 76:
#line 455 "Parser.jay"
  {
		yyVal = new PointerExpression ((FrameExpression) yyVals[-2+yyTop], (long) yyVals[0+yyTop]);
	  }
  break;
case 77:
#line 459 "Parser.jay"
  {
		yyVal = new RegisterExpression ((FrameExpression) yyVals[-3+yyTop], (string) yyVals[-1+yyTop], (long) yyVals[0+yyTop]);
	  }
  break;
case 78:
#line 463 "Parser.jay"
  {
		yyVal = new StructAccessExpression ((VariableExpression) yyVals[-2+yyTop], (string) yyVals[0+yyTop]);
	  }
  break;
case 79:
#line 467 "Parser.jay"
  {
		yyVal = new StructAccessExpression (new VariableDereferenceExpression ((VariableExpression) yyVals[-3+yyTop]), (string) yyVals[0+yyTop]);
	  }
  break;
case 80:
#line 471 "Parser.jay"
  {
		yyVal = new ArrayAccessExpression ((VariableExpression) yyVals[-3+yyTop], (Expression) yyVals[-1+yyTop]);
	  }
  break;
case 81:
#line 475 "Parser.jay"
  {
		yyVal = new ParentClassExpression ((VariableExpression) yyVals[-1+yyTop]);
	  }
  break;
case 82:
#line 479 "Parser.jay"
  {
		yyVal = (VariableExpression) yyVals[-1+yyTop];
	  }
  break;
case 83:
#line 486 "Parser.jay"
  {
		string[] args = new string [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (args, 0);
		yyVal = new ProgramArgumentsExpression (args);
	  }
  break;
case 84:
#line 495 "Parser.jay"
  {
		ArrayList args = new ArrayList ();
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 85:
#line 502 "Parser.jay"
  {
		ArrayList args = (ArrayList) yyVals[-1+yyTop];
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 86:
#line 512 "Parser.jay"
  {
		yyVal = ExamineCommand.Format.Standard;
	  }
  break;
case 87:
#line 516 "Parser.jay"
  {
		yyVal = new ExamineCommand.Format ((int)(long) yyVals[0+yyTop]);
	  }
  break;
case 88:
#line 523 "Parser.jay"
  {
		yyVal = (long) 0;
	  }
  break;
case 89:
#line 527 "Parser.jay"
  {
		yyVal = (long) yyVals[0+yyTop];
	  }
  break;
case 90:
#line 531 "Parser.jay"
  {
		yyVal = -(long) yyVals[0+yyTop];
	  }
  break;
case 91:
#line 538 "Parser.jay"
  {
		yyVal = (long)(int) yyVals[0+yyTop];
	  }
  break;
case 92:
#line 542 "Parser.jay"
  {
		yyVal = (long) yyVals[0+yyTop];
	  }
  break;
case 93:
#line 549 "Parser.jay"
  {
		yyVal = new BreakpointNumberExpression ((int) yyVals[0+yyTop]);
	  }
  break;
case 94:
#line 556 "Parser.jay"
  {
		yyVal = new ThreadGroupExpression ("main");
	  }
  break;
case 95:
#line 560 "Parser.jay"
  {
		yyVal = new ThreadGroupExpression ((string) yyVals[0+yyTop]);
	  }
  break;
case 96:
#line 564 "Parser.jay"
  {
		yyVal = new ThreadGroupExpression ("global");
	  }
  break;
case 97:
#line 571 "Parser.jay"
  {
		yyVal = new ProcessExpression (-1);
	  }
  break;
case 98:
#line 575 "Parser.jay"
  {
		yyVal = new ProcessExpression ((int) yyVals[0+yyTop]);
	  }
  break;
case 99:
#line 582 "Parser.jay"
  {
		yyVal = new FrameExpression ((ProcessExpression) yyVals[0+yyTop], -1);
	  }
  break;
case 100:
#line 586 "Parser.jay"
  {
		yyVal = new FrameExpression ((ProcessExpression) yyVals[-2+yyTop], (int) yyVals[0+yyTop]);
	  }
  break;
case 101:
#line 593 "Parser.jay"
  {
		yyVal = -1;
	  }
  break;
case 102:
#line 597 "Parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 103:
#line 604 "Parser.jay"
  {
		yyVal = new SourceExpression ((FrameExpression) yyVals[0+yyTop], null, -1);
	  }
  break;
case 104:
#line 608 "Parser.jay"
  {
		yyVal = new SourceExpression ((FrameExpression) yyVals[-2+yyTop], (string) yyVals[-1+yyTop], (int) yyVals[0+yyTop]);
	  }
  break;
case 105:
#line 612 "Parser.jay"
  {
		yyVal = new SourceExpression ((FrameExpression) yyVals[-1+yyTop], (int) yyVals[0+yyTop]);
	  }
  break;
case 106:
#line 616 "Parser.jay"
  {
		yyVal = new SourceExpression ((string) yyVals[0+yyTop]);
	  }
  break;
case 107:
#line 620 "Parser.jay"
  {
		yyVal = new SourceExpression ((string) yyVals[-2+yyTop], (int) yyVals[0+yyTop]);
	  }
  break;
case 108:
#line 624 "Parser.jay"
  {
		yyVal = new SourceExpression ((int) yyVals[0+yyTop]);
	  }
  break;
case 109:
#line 631 "Parser.jay"
  {
		int[] indices = new int [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (indices, 0);

		yyVal = new ModuleListExpression (indices);
	  }
  break;
case 110:
#line 641 "Parser.jay"
  {
		int[] indices = new int [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (indices, 0);

		yyVal = new SourceListExpression (indices);
	  }
  break;
case 111:
#line 651 "Parser.jay"
  {
		int[] indices = new int [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (indices, 0);

		yyVal = new ProcessListExpression (indices);
	  }
  break;
case 112:
#line 661 "Parser.jay"
  {
		ArrayList args = new ArrayList ();
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 113:
#line 668 "Parser.jay"
  {
		ArrayList args = (ArrayList) yyVals[-2+yyTop];
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 114:
#line 678 "Parser.jay"
  {
		yyVal = ModuleOperation.Ignore;
	  }
  break;
case 115:
#line 682 "Parser.jay"
  {
		yyVal = ModuleOperation.UnIgnore;
	  }
  break;
case 116:
#line 686 "Parser.jay"
  {
		yyVal = ModuleOperation.UnIgnore;
	  }
  break;
case 117:
#line 690 "Parser.jay"
  {
		yyVal = ModuleOperation.Step;
	  }
  break;
case 118:
#line 694 "Parser.jay"
  {
		yyVal = ModuleOperation.DontStep;
	  }
  break;
case 119:
#line 698 "Parser.jay"
  {
		yyVal = ModuleOperation.ShowBreakpoints;
	  }
  break;
case 120:
#line 705 "Parser.jay"
  {
		ModuleOperation[] operations = new ModuleOperation [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (operations, 0);

		yyVal = new ModuleOperationListExpression (operations);
	  }
  break;
case 121:
#line 715 "Parser.jay"
  {
		ArrayList args = new ArrayList ();
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 122:
#line 722 "Parser.jay"
  {
		ArrayList args = (ArrayList) yyVals[-1+yyTop];
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 123:
#line 732 "Parser.jay"
  {
		yyVal = BinaryOperator.Kind.Mult;
	  }
  break;
case 124:
#line 736 "Parser.jay"
  {
		yyVal = BinaryOperator.Kind.Plus;
	  }
  break;
case 125:
#line 740 "Parser.jay"
  {
		yyVal = BinaryOperator.Kind.Minus;
	  }
  break;
case 126:
#line 744 "Parser.jay"
  {
		yyVal = BinaryOperator.Kind.Div;
	  }
  break;
#line default
        }
        yyTop -= yyLen[yyN];
        yyState = yyStates[yyTop];
        int yyM = yyLhs[yyN];
        if (yyState == 0 && yyM == 0) {
          if (debug != null) debug.shift(0, yyFinal);
          yyState = yyFinal;
          if (yyToken < 0) {
            yyToken = yyLex.advance() ? yyLex.token() : 0;
            if (debug != null)
               debug.lex(yyState, yyToken,yyname(yyToken), yyLex.value());
          }
          if (yyToken == 0) {
            if (debug != null) debug.accept(yyVal);
            return yyVal;
          }
          goto yyLoop;
        }
        if (((yyN = yyGindex[yyM]) != 0) && ((yyN += yyState) >= 0)
            && (yyN < yyTable.Length) && (yyCheck[yyN] == yyState))
          yyState = yyTable[yyN];
        else
          yyState = yyDgoto[yyM];
        if (debug != null) debug.shift(yyStates[yyTop], yyState);
	 goto yyLoop;
      }
    }
  }

   static  short [] yyLhs  = {              -1,
    0,    0,    0,    0,    0,    1,    1,    1,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    3,    3,    3,    3,
    3,    3,   18,   18,   18,   18,   18,   18,    4,    4,
    4,    4,    4,    4,   15,   15,   15,   15,   15,   15,
   15,   15,    9,    9,    9,    9,    9,    9,    9,    9,
    9,    9,   17,   21,   21,   16,   16,   20,   20,   20,
   22,   22,   12,   10,   10,   10,    5,    5,    6,    6,
   23,   23,   11,   11,   11,   11,   11,   11,    7,    8,
   14,   24,   24,   25,   25,   25,   25,   25,   25,   13,
   26,   26,   19,   19,   19,   19,
  };
   static  short [] yyLen = {           2,
    0,    3,    2,    2,    2,    1,    1,    1,    2,    2,
    2,    2,    3,    2,    2,    2,    2,    2,    1,    1,
    2,    3,    3,    3,    2,    3,    3,    2,    2,    3,
    3,    3,    3,    3,    2,    2,    3,    2,    2,    2,
    3,    3,    4,    4,    2,    2,    2,    5,    2,    3,
    2,    2,    1,    1,    1,    1,    1,    1,    4,    3,
    4,    4,    4,    3,    4,    4,    4,    1,    1,    3,
    3,    1,    2,    2,    3,    3,    4,    3,    4,    4,
    4,    3,    1,    1,    2,    0,    2,    0,    2,    2,
    1,    1,    1,    0,    3,    3,    0,    2,    1,    3,
    0,    2,    1,    3,    2,    1,    3,    2,    1,    1,
    1,    1,    3,    1,    1,    2,    1,    2,    2,    1,
    1,    2,    1,    1,    1,    1,
  };
   static  short [] yyDefRed = {            0,
    0,    0,    5,    3,    4,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   19,    0,    0,   20,    0,
    0,    0,    0,    0,    0,    0,    6,    7,    8,    0,
    0,   35,   84,   52,    0,   21,    0,    0,    0,    0,
   25,    0,    0,   28,   29,   38,    9,   16,   17,   18,
   10,   11,   12,   14,   15,    0,    0,   69,   68,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   36,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   47,    0,    0,    0,    0,    0,   46,    0,   45,
    0,    0,    0,    0,    0,   39,   40,  112,    0,    0,
    2,   98,    0,   85,   22,   23,   24,    0,   26,   27,
    0,    0,    0,   31,   74,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  123,  124,  125,
  126,    0,   37,    0,    0,   53,   54,   55,   56,   57,
   58,    0,    0,    0,   64,    0,   93,   32,   33,   34,
   42,    0,    0,    0,  108,    0,  105,   91,   92,   87,
    0,    0,   13,    0,    0,  117,  114,  115,   41,  121,
    0,    0,  100,   95,   96,   82,   71,    0,    0,    0,
    0,    0,   76,   75,   78,    0,    0,    0,    0,    0,
    0,    0,    0,   43,    0,   44,  107,    0,  104,  118,
  116,  119,  122,  113,   81,   65,   66,   67,    0,    0,
   77,   79,   80,    0,  102,   89,   90,
  };
  protected static  short [] yyDgoto  = {             2,
   36,   37,   38,   39,   41,   77,  109,  120,   78,   67,
  100,  158,  179,  204,   79,  102,   44,  152,  142,  221,
   45,  170,  209,  110,  180,  181,
  };
  protected static  short [] yySindex = {         -218,
 -203, -185,    0,    0,    0, -207, -187, -110, -207, -207,
 -207, -207, -207, -207, -207, -207, -207, -207, -199, -104,
 -246, -183,  -68, -112, -179,    0, -167, -239,    0, -184,
 -229, -225, -207, -207, -145, -109,    0,    0,    0, -108,
 -102,    0,    0,    0, -103,    0, -207, -207, -207, -229,
    0, -145, -145,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, -258,  -85,    0,    0,  -93,
 -229, -104, -105,  -73,  -61,  -45, -205, -200,  -82, -207,
    0,  -81,  -40,  -30, -229,  -26,  -17,  -46,  -11,  -11,
  -11,    0,   -7,   -2,   15,  -22,    4,    0, -194,    0,
 -168, -229, -229, -200, -207,    0,    0,    0, -253,   -8,
    0,    0,    5,    0,    0,    0,    0, -200,    0,    0,
   -8,    6,    7,    0,    0, -200, -195,    2, -229, -229,
 -229, -229, -212,   20,   21,    8, -104,    0,    0,    0,
    0, -104,    0,   11, -229,    0,    0,    0,    0,    0,
    0, -229, -200, -229,    0, -229,    0,    0,    0,    0,
    0, -145, -145,   22,    0,    9,    0,    0,    0,    0,
 -200, -195,    0, -287,  -21,    0,    0,    0,    0,    0,
 -253,   23,    0,    0,    0,    0,    0,  -38,  -36,  -25,
  -23,  -53,    0,    0,    0,   25, -252,  -82, -229, -200,
 -200, -200, -200,    0,   -8,    0,    0,   31,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, -168, -168,
    0,    0,    0, -200,    0,    0,    0,
  };
  protected static  short [] yyRindex = {            1,
    0,    0,    0,    0,    0, -215,    0,    0,   34,   34,
   34,   34,   34,   34,   34,   34,   34,   34,  -47, -232,
 -215,    0,    0,    0,    0,    0,    0,    3,    0,  -65,
 -232,    0,   34,   34,    0,    0,    0,    0,    0,    0,
  -97,    0,    0,    0,   37,    0, -215, -215, -215, -232,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    3,    0,    0,    0,
 -232, -232,    0,    0,    0,    0,    0, -155,   38, -215,
    0,    0,    0,    0, -232,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   39,    0,    0,   40,    0,
    0, -232, -232,   41,   34,    0,    0,    0,    0, -255,
    0,    0,    0,    0,    0,    0,    0,   42,    0,    0,
   43,    0,    0,    0,    0,  -67, -170,    0, -232, -232,
 -232, -232,    0,    0,    0,    0, -232,    0,    0,    0,
    0, -232,    0,    0, -232,    0,    0,    0,    0,    0,
    0, -232,   44, -232,    0, -232,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   45,    0,    0,    0,    0,
   46,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   47,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, -164,    0,    0,    0,    0,    0, -223, -232,   48,
   49,   50,   51,    0, -109,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   52,    0,    0,    0,
  };
  protected static  short [] yyGindex = {            0,
    0,    0,    0,    0,   -3,   -1,  259,    0,  -31,    0,
  245,   18,    0,  172,  -55,    0,    0,    0,    0,    0,
    0,   29,    0,  -51,  160,    0,
  };
  protected static  short [] yyTable = {           104,
    1,  121,  109,  122,   42,   56,   57,   58,   59,   60,
   61,   62,   63,   64,   65,  109,  128,  174,  118,   81,
   40,  138,  139,  140,  141,   96,   99,   40,  223,  106,
  107,   97,  210,   97,   70,   97,   97,   40,    1,  126,
  127,   70,   97,   80,   71,  115,  116,  117,  103,  192,
   97,  193,  123,  153,    3,   70,  211,   70,  109,   40,
  175,   73,  133,  134,  109,   99,  176,  166,  167,  135,
  171,  172,    4,    5,  135,  136,   98,   43,  143,  137,
  136,  197,   66,  186,  137,   92,  198,   82,  109,  109,
  177,  178,  101,   88,  168,  169,  105,  188,  189,  190,
  191,  173,   72,   72,   72,   88,   72,  159,  160,   88,
  205,  205,   88,  200,   88,   88,   88,  108,   72,   72,
  201,   72,  202,   72,  203,   72,    6,    7,    8,    9,
   10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
   20,   21,   22,   23,   24,   25,   26,   27,  111,   28,
   29,   30,   31,   32,  112,   33,   34,   35,   68,   69,
   99,  114,   40,  113,   99,   99,   70,  224,  125,   71,
   99,   99,  129,   72,   46,   47,   48,   49,   50,   96,
  144,   40,   93,   94,   95,   97,   73,   74,   75,   76,
   73,  138,  139,  140,  141,   51,   52,   53,   54,   55,
   86,   86,   86,   86,  130,   86,   73,   73,   86,   73,
   94,   73,   86,   73,   94,   94,  131,   94,   94,   94,
   83,  219,  220,   94,  145,   86,   84,   85,   86,   87,
   88,  135,  132,  135,   89,   90,   91,  136,  154,  136,
  215,  137,  216,  137,  135,  155,  135,  226,  227,  156,
  136,  157,  136,  217,  137,  218,  137,  161,    1,    1,
   97,  164,  162,  182,   97,   97,  165,  183,   97,  146,
  147,  148,  149,  150,  151,  138,  139,  140,  141,  163,
  187,  194,  195,  199,  207,  214,  222,  212,  184,  185,
  196,   97,  208,  225,   83,   49,  106,  103,   51,   30,
  110,   60,  101,   50,  120,   62,   59,   63,   61,   48,
  119,  124,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,  206,    1,    1,    1,    1,    1,
  213,    1,    1,    1,
  };
  protected static  short [] yyCheck = {            31,
    0,   53,  258,  262,    6,    9,   10,   11,   12,   13,
   14,   15,   16,   17,   18,  271,   72,  271,   50,   21,
  267,  274,  275,  276,  277,  265,   28,  267,  281,   33,
   34,  271,  320,  266,  258,  268,  269,  267,  257,   71,
   72,  271,  258,  290,  274,   47,   48,   49,  278,  262,
  266,  264,  311,   85,  258,  279,  344,  281,  314,  267,
  314,  291,  268,  269,  320,   67,  320,  262,  263,  270,
  102,  103,  258,  259,  270,  276,  316,  265,   80,  280,
  276,  137,  282,  279,  280,  265,  142,  271,  344,  345,
  344,  345,  277,  258,  263,  264,  322,  129,  130,  131,
  132,  105,  258,  274,  275,  270,  277,   90,   91,  274,
  162,  163,  277,  145,  279,  280,  281,  263,  274,  275,
  152,  277,  154,  279,  156,  281,  312,  313,  314,  315,
  316,  317,  318,  319,  320,  321,  322,  323,  324,  325,
  326,  327,  328,  329,  330,  331,  332,  333,  258,  335,
  336,  337,  338,  339,  263,  341,  342,  343,  263,  264,
  258,  265,  267,  266,  262,  263,  271,  199,  262,  274,
  268,  269,  278,  278,  285,  286,  287,  288,  289,  265,
  262,  267,  350,  351,  352,  271,  291,  292,  293,  294,
  258,  274,  275,  276,  277,  306,  307,  308,  309,  310,
  266,  267,  268,  269,  278,  271,  274,  275,  274,  277,
  258,  279,  278,  281,  262,  263,  278,  265,  266,  267,
  289,  275,  276,  271,  265,  291,  295,  296,  297,  298,
  299,  270,  278,  270,  347,  348,  349,  276,  265,  276,
  279,  280,  279,  280,  270,  263,  270,  219,  220,  296,
  276,  263,  276,  279,  280,  279,  280,  265,  258,  259,
  258,  284,  265,  272,  262,  263,  263,  263,  266,  300,
  301,  302,  303,  304,  305,  274,  275,  276,  277,  265,
  279,  262,  262,  273,  263,  263,  262,  309,  283,  283,
  283,  258,  284,  263,  258,  258,  258,  258,  258,  258,
  258,  258,  258,  258,  258,  258,  258,  258,  258,  258,
   52,   67,  312,  313,  314,  315,  316,  317,  318,  319,
  320,  321,  322,  323,  324,  325,  326,  327,  328,  329,
  330,  331,  332,  333,  163,  335,  336,  337,  338,  339,
  181,  341,  342,  343,
  };

#line 749 "Parser.jay"

public Parser (ScriptingContext context, string name)
{
	this.name = name;
	this.reader = new MyTextReader ();
	this.current_context = context;

	lexer = new Tokenizer (context, reader, name);
}

public bool Parse (string text)
{
	try {
		reader.Text = text;
		lexer.restart ();
		if (yacc_verbose_flag)
			yyparse (lexer, new yydebug.yyDebugSimple ());
		else
			yyparse (lexer);
		return true;
	} catch (Exception e){
		// Please do not remove this, it is used during debugging
		// of the grammar
		//
		current_context.Error (lexer.location + "  : Parsing error ");
		current_context.Error (e.ToString ());
		return false;
	}
}

/* end end end */
}
#line default
namespace yydebug {
        using System;
	 public interface yyDebug {
		 void push (int state, Object value);
		 void lex (int state, int token, string name, Object value);
		 void shift (int from, int to, int errorFlag);
		 void pop (int state);
		 void discard (int state, int token, string name, Object value);
		 void reduce (int from, int to, int rule, string text, int len);
		 void shift (int from, int to);
		 void accept (Object value);
		 void error (string message);
		 void reject ();
	 }
	 
	 class yyDebugSimple : yyDebug {
		 void println (string s){
			 Console.WriteLine (s);
		 }
		 
		 public void push (int state, Object value) {
			 println ("push\tstate "+state+"\tvalue "+value);
		 }
		 
		 public void lex (int state, int token, string name, Object value) {
			 println("lex\tstate "+state+"\treading "+name+"\tvalue "+value);
		 }
		 
		 public void shift (int from, int to, int errorFlag) {
			 switch (errorFlag) {
			 default:				// normally
				 println("shift\tfrom state "+from+" to "+to);
				 break;
			 case 0: case 1: case 2:		// in error recovery
				 println("shift\tfrom state "+from+" to "+to
					     +"\t"+errorFlag+" left to recover");
				 break;
			 case 3:				// normally
				 println("shift\tfrom state "+from+" to "+to+"\ton error");
				 break;
			 }
		 }
		 
		 public void pop (int state) {
			 println("pop\tstate "+state+"\ton error");
		 }
		 
		 public void discard (int state, int token, string name, Object value) {
			 println("discard\tstate "+state+"\ttoken "+name+"\tvalue "+value);
		 }
		 
		 public void reduce (int from, int to, int rule, string text, int len) {
			 println("reduce\tstate "+from+"\tuncover "+to
				     +"\trule ("+rule+") "+text);
		 }
		 
		 public void shift (int from, int to) {
			 println("goto\tfrom state "+from+" to "+to);
		 }
		 
		 public void accept (Object value) {
			 println("accept\tvalue "+value);
		 }
		 
		 public void error (string message) {
			 println("error\t"+message);
		 }
		 
		 public void reject () {
			 println("reject");
		 }
		 
	 }
}
// %token constants
 class Token {
  public const int QUIT = 257;
  public const int EOL = 258;
  public const int EOF = 259;
  public const int NONE = 260;
  public const int ERROR = 261;
  public const int IDENTIFIER = 262;
  public const int INTEGER = 263;
  public const int NUMBER = 264;
  public const int STRING = 265;
  public const int HASH = 266;
  public const int AT = 267;
  public const int PERCENT = 268;
  public const int DOLLAR = 269;
  public const int DOT = 270;
  public const int BANG = 271;
  public const int COMMA = 272;
  public const int ASSIGN = 273;
  public const int STAR = 274;
  public const int PLUS = 275;
  public const int MINUS = 276;
  public const int DIV = 277;
  public const int OPEN_PARENS = 278;
  public const int CLOSE_PARENS = 279;
  public const int OPEN_BRACKET = 280;
  public const int CLOSE_BRACKET = 281;
  public const int OP_LT = 282;
  public const int OP_GT = 283;
  public const int COLON = 284;
  public const int PROCESSES = 285;
  public const int REGISTERS = 286;
  public const int PARAMETERS = 287;
  public const int LOCALS = 288;
  public const int TYPE = 289;
  public const int METHOD = 290;
  public const int PARENT = 291;
  public const int LENGTH = 292;
  public const int LOWER = 293;
  public const int UPPER = 294;
  public const int KIND = 295;
  public const int ACCESSIBLE = 296;
  public const int CONTENTS = 297;
  public const int LINE = 298;
  public const int NOT = 299;
  public const int UNKNOWN = 300;
  public const int FUNDAMENTAL = 301;
  public const int ARRAY = 302;
  public const int STRUCT = 303;
  public const int CLASS = 304;
  public const int POINTER = 305;
  public const int MODULES = 306;
  public const int SOURCES = 307;
  public const int METHODS = 308;
  public const int BREAKPOINTS = 309;
  public const int THREADGROUPS = 310;
  public const int GLOBAL = 311;
  public const int FRAME = 312;
  public const int START = 313;
  public const int SHOW = 314;
  public const int PROCESS = 315;
  public const int CONTINUE = 316;
  public const int BACKTRACE = 317;
  public const int UP = 318;
  public const int DOWN = 319;
  public const int STEP = 320;
  public const int NEXT = 321;
  public const int STEPI = 322;
  public const int NEXTI = 323;
  public const int FINISH = 324;
  public const int BREAK = 325;
  public const int PRINT = 326;
  public const int DISASSEMBLE = 327;
  public const int SET = 328;
  public const int ASSERT = 329;
  public const int BREAKPOINT = 330;
  public const int SAVE = 331;
  public const int KILL = 332;
  public const int THREADGROUP = 333;
  public const int SEARCH = 334;
  public const int LIST = 335;
  public const int RUN = 336;
  public const int EXAMINE = 337;
  public const int CALL = 338;
  public const int NATIVE = 339;
  public const int SELECT = 340;
  public const int BACKGROUND = 341;
  public const int STOP = 342;
  public const int MODULE = 343;
  public const int IGNORE = 344;
  public const int UNIGNORE = 345;
  public const int ALL = 346;
  public const int ENABLE = 347;
  public const int DISABLE = 348;
  public const int DELETE = 349;
  public const int CREATE = 350;
  public const int ADD = 351;
  public const int REMOVE = 352;
  public const int HELP = 353;
  public const int yyErrorCode = 256;
 }
 namespace yyParser {
  using System;
  /** thrown for irrecoverable syntax errors and stack overflow.
    */
  public class yyException : System.Exception {
    public yyException (string message) : base (message) {
    }
  }

  /** must be implemented by a scanner object to supply input to the parser.
    */
  public interface yyInput {
    /** move on to next token.
        @return false if positioned beyond tokens.
        @throws IOException on input error.
      */
    bool advance (); // throws java.io.IOException;
    /** classifies current token.
        Should not be called if advance() returned false.
        @return current %token or single character.
      */
    int token ();
    /** associated with current token.
        Should not be called if advance() returned false.
        @return value for token().
      */
    Object value ();
  }
 }
} // close outermost namespace, that MUST HAVE BEEN opened in the prolog
